@@ -1,4 +1,5 @@
 """Abstraction layer to construct a workflow node using and airflow operator."""
+
 from collections.abc import Iterable
 from typing import Type
 
@@ -7,7 +8,6 @@ from airflow.operators.bash import BashOperator
 from dkist_processing_core.resource_queue import ResourceQueue
 from dkist_processing_core.task import TaskBase
 
-
 task_type_hint = Type[TaskBase]
 upstreams_type_hint = list[task_type_hint] | task_type_hint | None
 
@@ -50,9 +50,10 @@ class Node:
     def operator(self) -> BashOperator:
         """Native engine node."""
         from datetime import timedelta
-        from dkist_processing_core.failure_callback import chat_ops_notification
         from functools import partial
 
+        from dkist_processing_core.failure_callback import chat_ops_notification
+
         return eval(self.operator_definition)
 
     @property
@@ -93,6 +94,8 @@ class Node:
     def bash_script(self) -> str:
         """Format bash script for the BashOperator."""
         command = f"""{self.install_command}
+echo Virtual Python Environment Packages
+pip list
 {self.run_command}"""
         return self.bash_template(command)
 
@@ -115,7 +118,7 @@ echo Host Python Environment i.e. system-site-packages
 python3 -m pip install --upgrade --user pip
 pip list
 echo Creating Virtual Environment
-python3 -m venv --system-site-packages .task_venv
+python3 -m venv .task_venv
 echo Activate Environment
 . .task_venv/bin/activate
 echo Python Interpreter Location
